@@ -97,42 +97,34 @@ LayerTabBar::~LayerTabBar()
 {
 }
 
-/*************************************************************************
-|*
-\************************************************************************/
-
 void LayerTabBar::Select()
 {
     SfxDispatcher* pDispatcher = pDrViewSh->GetViewFrame()->GetDispatcher();
     pDispatcher->Execute(SID_SWITCHLAYER, SFX_CALLMODE_ASYNCHRON);
 }
 
-/*************************************************************************
-|*
-\************************************************************************/
-
 void LayerTabBar::MouseButtonDown(const MouseEvent& rMEvt)
 {
-    BOOL bSetPageID=FALSE;
+    sal_Bool bSetPageID=sal_False;
 
     if (rMEvt.IsLeft() && !rMEvt.IsMod1() && !rMEvt.IsMod2())
     {
         Point aPosPixel = rMEvt.GetPosPixel();
-        USHORT aLayerId = GetPageId( PixelToLogic(aPosPixel) );
+        sal_uInt16 aLayerId = GetPageId( PixelToLogic(aPosPixel) );
 
         if (aLayerId == 0)
         {
             SfxDispatcher* pDispatcher = pDrViewSh->GetViewFrame()->GetDispatcher();
             pDispatcher->Execute(SID_INSERTLAYER, SFX_CALLMODE_SYNCHRON);
 
-            bSetPageID=TRUE;
+            bSetPageID=sal_True;
         }
         else if (rMEvt.IsShift())
         {
             // Toggle zw. Layer sichtbar / unsichtbar
             String aName(GetPageText(aLayerId));
             SdrPageView* pPV = pDrViewSh->GetView()->GetSdrPageView();
-            BOOL bVisible = pPV->IsLayerVisible(aName);
+            sal_Bool bVisible = pPV->IsLayerVisible(aName);
             pPV->SetLayerVisible(aName, !bVisible);
             pDrViewSh->ResetActualLayer();
         }
@@ -144,10 +136,6 @@ void LayerTabBar::MouseButtonDown(const MouseEvent& rMEvt)
         TabBar::MouseButtonDown(rMEvt);
 }
 
-/*************************************************************************
-|*
-\************************************************************************/
-
 void LayerTabBar::DoubleClick()
 {
     if (GetCurPageId() != 0)
@@ -173,9 +161,9 @@ sal_Int8 LayerTabBar::AcceptDrop( const AcceptDropEvent& rEvt )
 
     if( !pDrViewSh->GetDocSh()->IsReadOnly() )
     {
-        USHORT			nPageId = SDRPAGE_NOTFOUND;
+        sal_uInt16			nPageId = SDRPAGE_NOTFOUND;
         Point			aPos( PixelToLogic( rEvt.maPosPixel ) );
-        USHORT			nLayerId = pDrViewSh->GetView()->GetDoc()->GetLayerAdmin().GetLayerID( GetPageText( GetPageId( aPos ) ), FALSE );
+        sal_uInt16			nLayerId = pDrViewSh->GetView()->GetDoc()->GetLayerAdmin().GetLayerID( GetPageText( GetPageId( aPos ) ), sal_False );
 
         nRet = pDrViewSh->AcceptDrop( rEvt, *this, NULL, nPageId, nLayerId );
 
@@ -193,8 +181,8 @@ sal_Int8 LayerTabBar::AcceptDrop( const AcceptDropEvent& rEvt )
 
 sal_Int8 LayerTabBar::ExecuteDrop( const ExecuteDropEvent& rEvt )
 {
-    USHORT			nPageId = SDRPAGE_NOTFOUND;
-    USHORT			nLayerId = pDrViewSh->GetView()->GetDoc()->GetLayerAdmin().GetLayerID( GetPageText( GetPageId( PixelToLogic( rEvt.maPosPixel ) ) ), FALSE );
+    sal_uInt16			nPageId = SDRPAGE_NOTFOUND;
+    sal_uInt16			nLayerId = pDrViewSh->GetView()->GetDoc()->GetLayerAdmin().GetLayerID( GetPageText( GetPageId( PixelToLogic( rEvt.maPosPixel ) ) ), sal_False );
     sal_Int8		nRet = pDrViewSh->ExecuteDrop( rEvt, *this, NULL, nPageId, nLayerId );
 
     EndSwitchPage();
@@ -203,10 +191,6 @@ sal_Int8 LayerTabBar::ExecuteDrop( const ExecuteDropEvent& rEvt )
 
 }
 
-/*************************************************************************
-|*
-\************************************************************************/
-
 void  LayerTabBar::Command(const CommandEvent& rCEvt)
 {
     if ( rCEvt.GetCommand() == COMMAND_CONTEXTMENU )
@@ -216,13 +200,9 @@ void  LayerTabBar::Command(const CommandEvent& rCEvt)
     }
 }
 
-
-/*************************************************************************
-|*
-\************************************************************************/
 long LayerTabBar::StartRenaming()
 {
-    BOOL bOK = TRUE;
+    sal_Bool bOK = sal_True;
     String aLayerName = GetPageText( GetEditPageId() );
     String aLayoutLayer ( SdResId(STR_LAYER_LAYOUT) );
     String aControlsLayer ( SdResId(STR_LAYER_CONTROLS) );
@@ -235,7 +215,7 @@ long LayerTabBar::StartRenaming()
          aLayerName == aBackgroundLayer   || aLayerName == aBackgroundObjLayer )
     {
         // Diese Namen duerfen nicht veraendert werden
-        bOK = FALSE;
+        bOK = sal_False;
     }
     else
     {
@@ -250,13 +230,9 @@ long LayerTabBar::StartRenaming()
     return(bOK);
 }
 
-/*************************************************************************
-|*
-\************************************************************************/
-
 long LayerTabBar::AllowRenaming()
 {
-    BOOL bOK = TRUE;
+    sal_Bool bOK = sal_True;
 
     // Ueberpruefung auf schon vorhandene Namen
     ::sd::View* pView = pDrViewSh->GetView();
@@ -266,13 +242,13 @@ long LayerTabBar::AllowRenaming()
     String aNewName( GetEditText() );
 
     if ( aNewName.Len() == 0 ||
-        (rLayerAdmin.GetLayer( aNewName, FALSE ) && aLayerName != aNewName) )
+        (rLayerAdmin.GetLayer( aNewName, sal_False ) && aLayerName != aNewName) )
     {
         // Name ist schon vorhanden
         WarningBox aWarningBox( &pDrViewSh->GetViewFrame()->GetWindow(), WinBits( WB_OK ),
                                 String(SdResId( STR_WARN_NAME_DUPLICATE ) ) );
         aWarningBox.Execute();
-        bOK = FALSE;
+        bOK = sal_False;
     }
 
     if (bOK)
@@ -288,17 +264,13 @@ long LayerTabBar::AllowRenaming()
              aNewName == aBackgroundLayer   || aNewName == aBackgroundObjLayer )
         {
             // Diese Namen duerfen nicht vergeben werden
-            bOK = FALSE;
+            bOK = sal_False;
         }
     }
 
     return(bOK);
 }
 
-/*************************************************************************
-|*
-\************************************************************************/
-
 void LayerTabBar::EndRenaming()
 {
     if( !IsEditModeCanceled() )
@@ -309,7 +281,7 @@ void LayerTabBar::EndRenaming()
         SdDrawDocument* pDoc = pView->GetDoc();
         String aLayerName = pView->GetActiveLayer();
         SdrLayerAdmin& rLayerAdmin = pDoc->GetLayerAdmin();
-        SdrLayer* pLayer = rLayerAdmin.GetLayer(aLayerName, FALSE);
+        SdrLayer* pLayer = rLayerAdmin.GetLayer(aLayerName, sal_False);
 
         if (pLayer)
         {
@@ -318,7 +290,7 @@ void LayerTabBar::EndRenaming()
             DBG_ASSERT( pDrView, "Rename layer undo action is only working with a SdDrawView" );
             if( pDrView )
             {
-                SfxUndoManager* pManager = pDoc->GetDocSh()->GetUndoManager();
+                ::svl::IUndoManager* pManager = pDoc->GetDocSh()->GetUndoManager();
                 SdLayerModifyUndoAction* pAction = new SdLayerModifyUndoAction(
                     pDoc,
                     pLayer,
@@ -343,16 +315,11 @@ void LayerTabBar::EndRenaming()
             // schon bekannt sein muss.
             pView->SetActiveLayer(aNewName);
             pLayer->SetName(aNewName);
-            pDoc->SetChanged(TRUE);
+            pDoc->SetChanged(sal_True);
         }
     }
 }
 
-
-/*************************************************************************
-|*
-\************************************************************************/
-
 void LayerTabBar::ActivatePage()
 {
     if ( /*IsInSwitching*/ 1 && pDrViewSh!=NULL)
