@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -35,18 +36,14 @@
 #include <sfx2/docfac.hxx>
 #include <sfx2/objface.hxx>
 
-#ifndef _SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <svl/srchitem.hxx>
 #include <svx/srchdlg.hxx>
 #include <editeng/flstitem.hxx>
 #include <svl/eitem.hxx>
 #include <svl/intitem.hxx>
 #include <sfx2/printer.hxx>
-#ifndef _SFX_DOCFILE_HXX //autogen
 #include <sfx2/docfile.hxx>
-#endif
 #include <svx/drawitem.hxx>
 #include <editeng/flstitem.hxx>
 #include <svx/drawitem.hxx>
@@ -56,9 +53,7 @@
 #include <svl/itempool.hxx>
 #include <svtools/ctrltool.hxx>
 #include <svtools/filter.hxx>
-#ifndef _SO_CLSIDS_HXX
 #include <sot/clsids.hxx>
-#endif
 #include <svl/cjkoptions.hxx>
 #include <svl/visitem.hxx>
 
@@ -80,13 +75,9 @@
 #include "fusearch.hxx"
 #include "ViewShell.hxx"
 #include "sdresid.hxx"
-#ifndef SD_FU_SLIDE_SHOW_DLG_HXX
 #include "slideshow.hxx"
-#endif
 #include "drawview.hxx"
-#ifndef SD_FRAMW_VIEW_HXX
 #include "FrameView.hxx"
-#endif
 #include "unomodel.hxx"
 #include "undo/undomanager.hxx"
 #include "undo/undofactory.hxx"
@@ -100,15 +91,14 @@ using namespace sd;
 SFX_IMPL_INTERFACE(DrawDocShell, SfxObjectShell, SdResId(0))
 {
     SFX_CHILDWINDOW_REGISTRATION(SvxSearchDialogWrapper::GetChildWindowId());
-        SFX_CHILDWINDOW_REGISTRATION(SID_HYPERLINK_INSERT);
 }
 
 
 namespace sd {
 
-#define POOL_BUFFER_SIZE				(USHORT)32768
-#define BASIC_BUFFER_SIZE				(USHORT)8192
-#define DOCUMENT_BUFFER_SIZE            (USHORT)32768
+#define POOL_BUFFER_SIZE				(sal_uInt16)32768
+#define BASIC_BUFFER_SIZE				(sal_uInt16)8192
+#define DOCUMENT_BUFFER_SIZE            (sal_uInt16)32768
 
 
 GraphicFilter* GetGrfFilter();
@@ -134,7 +124,7 @@ SFX_IMPL_OBJECTFACTORY(
 
 void DrawDocShell::Construct( bool bClipboard )
 {
-    mbInDestruction = FALSE;
+    mbInDestruction = sal_False;
     SetSlotFilter();     // setzt Filter zurueck
 
     mbOwnDocument = mpDoc == 0;
@@ -161,7 +151,7 @@ void DrawDocShell::Construct( bool bClipboard )
 \************************************************************************/
 
 DrawDocShell::DrawDocShell(SfxObjectCreateMode eMode,
-                               BOOL bDataObject,
+                               sal_Bool bDataObject,
                                DocumentType eDocumentType) :
     SfxObjectShell( eMode == SFX_CREATE_MODE_INTERNAL ?  SFX_CREATE_MODE_EMBEDDED : eMode),
     mpDoc(NULL),
@@ -172,7 +162,7 @@ DrawDocShell::DrawDocShell(SfxObjectCreateMode eMode,
     meDocType(eDocumentType),
     mpFilterSIDs(0),
     mbSdDataObj(bDataObject),
-    mbOwnPrinter(FALSE),
+    mbOwnPrinter(sal_False),
     mbNewDocument( sal_True )
 {
     Construct( eMode == SFX_CREATE_MODE_INTERNAL );
@@ -184,7 +174,7 @@ DrawDocShell::DrawDocShell(SfxObjectCreateMode eMode,
 |*
 \************************************************************************/
 
-DrawDocShell::DrawDocShell( const sal_uInt64 nModelCreationFlags, BOOL bDataObject, DocumentType eDocumentType ) :
+DrawDocShell::DrawDocShell( const sal_uInt64 nModelCreationFlags, sal_Bool bDataObject, DocumentType eDocumentType ) :
     SfxObjectShell( nModelCreationFlags ),
     mpDoc(NULL),
     mpUndoManager(NULL),
@@ -194,10 +184,10 @@ DrawDocShell::DrawDocShell( const sal_uInt64 nModelCreationFlags, BOOL bDataObje
     meDocType(eDocumentType),
     mpFilterSIDs(0),
     mbSdDataObj(bDataObject),
-    mbOwnPrinter(FALSE),
+    mbOwnPrinter(sal_False),
     mbNewDocument( sal_True )
 {
-    Construct( FALSE );
+    Construct( sal_False );
 }
 
 /*************************************************************************
@@ -207,7 +197,7 @@ DrawDocShell::DrawDocShell( const sal_uInt64 nModelCreationFlags, BOOL bDataObje
 \************************************************************************/
 
 DrawDocShell::DrawDocShell(SdDrawDocument* pDoc, SfxObjectCreateMode eMode,
-                               BOOL bDataObject,
+                               sal_Bool bDataObject,
                                DocumentType eDocumentType) :
     SfxObjectShell(eMode == SFX_CREATE_MODE_INTERNAL ?  SFX_CREATE_MODE_EMBEDDED : eMode),
     mpDoc(pDoc),
@@ -218,7 +208,7 @@ DrawDocShell::DrawDocShell(SdDrawDocument* pDoc, SfxObjectCreateMode eMode,
     meDocType(eDocumentType),
     mpFilterSIDs(0),
     mbSdDataObj(bDataObject),
-    mbOwnPrinter(FALSE),
+    mbOwnPrinter(sal_False),
     mbNewDocument( sal_True )
 {
     Construct( eMode == SFX_CREATE_MODE_INTERNAL );
@@ -238,7 +228,7 @@ DrawDocShell::~DrawDocShell()
     // may be usefull in other places as well.
     Broadcast(SfxSimpleHint(SFX_HINT_DYING));
 
-    mbInDestruction = TRUE;
+    mbInDestruction = sal_True;
 
     SetDocShellFunction(0);
 
@@ -255,7 +245,7 @@ DrawDocShell::~DrawDocShell()
         delete mpDoc;
 
     // damit der Navigator das Verschwinden des Dokuments mitbekommt
-    SfxBoolItem		aItem(SID_NAVIGATOR_INIT, TRUE);
+    SfxBoolItem		aItem(SID_NAVIGATOR_INIT, sal_True);
     SfxViewFrame*	pFrame = mpViewShell ? mpViewShell->GetFrame() : GetFrame();
 
     if( !pFrame )
@@ -276,11 +266,11 @@ void DrawDocShell::GetState(SfxItemSet &rSet)
 {
 
     SfxWhichIter aIter( rSet );
-    USHORT nWhich = aIter.FirstWhich();
+    sal_uInt16 nWhich = aIter.FirstWhich();
 
     while ( nWhich )
     {
-        USHORT nSlotId = SfxItemPool::IsWhich(nWhich)
+        sal_uInt16 nSlotId = SfxItemPool::IsWhich(nWhich)
             ? GetPool().GetSlotId(nWhich)
             : nWhich;
 
@@ -294,7 +284,7 @@ void DrawDocShell::GetState(SfxItemSet &rSet)
 
             case SID_CLOSEDOC:
             {
-                BOOL bDisabled = FALSE;
+                sal_Bool bDisabled = sal_False;
                 if (bDisabled)
                 {
                     rSet.DisableItem(SID_CLOSEDOC);
@@ -308,7 +298,7 @@ void DrawDocShell::GetState(SfxItemSet &rSet)
 
             case SID_SEARCH_OPTIONS:
             {
-                UINT16 nOpt = SEARCH_OPTIONS_SEARCH 	 |
+                sal_uInt16 nOpt = SEARCH_OPTIONS_SEARCH 	 |
                               SEARCH_OPTIONS_WHOLE_WORDS |
                               SEARCH_OPTIONS_BACKWARDS	 |
                               SEARCH_OPTIONS_REG_EXP	 |
@@ -357,7 +347,7 @@ void DrawDocShell::GetState(SfxItemSet &rSet)
     }
 }
 
-void DrawDocShell::InPlaceActivate( BOOL bActive )
+void DrawDocShell::InPlaceActivate( sal_Bool bActive )
 {
     if( !bActive )
     {
@@ -437,7 +427,7 @@ void DrawDocShell::InPlaceActivate( BOOL bActive )
 |*
 \************************************************************************/
 
-void DrawDocShell::Activate( BOOL bMDI)
+void DrawDocShell::Activate( sal_Bool bMDI)
 {
     if (bMDI)
     {
@@ -452,7 +442,7 @@ void DrawDocShell::Activate( BOOL bMDI)
 |*
 \************************************************************************/
 
-void DrawDocShell::Deactivate( BOOL )
+void DrawDocShell::Deactivate( sal_Bool )
 {
 }
 
@@ -462,7 +452,7 @@ void DrawDocShell::Deactivate( BOOL )
 |*
 \************************************************************************/
 
-SfxUndoManager* DrawDocShell::GetUndoManager()
+::svl::IUndoManager* DrawDocShell::GetUndoManager()
 {
     return mpUndoManager;
 }
@@ -487,12 +477,6 @@ void DrawDocShell::UpdateTablePointers()
     UpdateFontList();
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void DrawDocShell::CancelSearching()
 {
     if( dynamic_cast<FuSearch*>( mxDocShellFunction.get() ) )
@@ -526,19 +510,19 @@ void DrawDocShell::ApplySlotFilter() const
                 pDispatcher->SetSlotFilter();
 
             if( pDispatcher->GetBindings() )
-                pDispatcher->GetBindings()->InvalidateAll( TRUE );
+                pDispatcher->GetBindings()->InvalidateAll( sal_True );
         }
 
         pTestViewShell = SfxViewShell::GetNext( *pTestViewShell );
     }
 }
 
-void DrawDocShell::SetModified( BOOL bSet /* = TRUE */ )
+void DrawDocShell::SetModified( sal_Bool bSet /* = sal_True */ )
 {
     SfxObjectShell::SetModified( bSet );
 
-    // #100237# change model state, too
-    // #103182# only set the changed state if modification is enabled
+    // change model state, too
+    // only set the changed state if modification is enabled
     if( IsEnableSetModified() )
     {
         if ( mpDoc )
@@ -554,7 +538,7 @@ void DrawDocShell::SetModified( BOOL bSet /* = TRUE */ )
 |*
 \************************************************************************/
 
-// #91457# ExecuteSpellPopup now handled by DrawDocShell. This is necessary
+// ExecuteSpellPopup now handled by DrawDocShell. This is necessary
 // to get hands on the outliner and the text object.
 IMPL_LINK(DrawDocShell, OnlineSpellCallback, SpellCallbackInfo*, pInfo)
 {
@@ -600,9 +584,11 @@ void DrawDocShell::ClearUndoBuffer()
         pSfxViewFrame = SfxViewFrame::GetNext(*pSfxViewFrame, this, false);
     }
     
-    SfxUndoManager* pUndoManager = GetUndoManager();
+    ::svl::IUndoManager* pUndoManager = GetUndoManager();
     if(pUndoManager && pUndoManager->GetUndoActionCount())
         pUndoManager->Clear();
 }
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
