@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -63,7 +64,7 @@ Reference<XInterface> SAL_CALL PresenterCanvas_createInstance (
 
 ::rtl::OUString PresenterCanvas_getImplementationName (void) throw(RuntimeException)
 {
-    return OUString::createFromAscii("com.sun.star.comp.Draw.PresenterCanvasFactory");
+    return OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Draw.PresenterCanvasFactory"));
 }
 
 
@@ -73,7 +74,7 @@ Sequence<rtl::OUString> SAL_CALL PresenterCanvas_getSupportedServiceNames (void)
     throw (RuntimeException)
 {
     static const ::rtl::OUString sServiceName(
-        ::rtl::OUString::createFromAscii("com.sun.star.rendering.Canvas"));
+        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.rendering.Canvas")));
     return Sequence<rtl::OUString>(&sServiceName, 1);
 }
 
@@ -232,7 +233,7 @@ void SAL_CALL PresenterCanvas::initialize (
             if ( ! (rArguments[2] >>= mxSharedWindow))
             {
                 throw lang::IllegalArgumentException(
-                    OUString::createFromAscii("PresenterCanvas: invalid shared window"),
+                    OUString(RTL_CONSTASCII_USTRINGPARAM("PresenterCanvas: invalid shared window")),
                     static_cast<XWeak*>(this),
                     1);
             }
@@ -240,7 +241,7 @@ void SAL_CALL PresenterCanvas::initialize (
             if ( ! (rArguments[3] >>= mxSharedCanvas))
             {
                 throw lang::IllegalArgumentException(
-                    OUString::createFromAscii("PresenterCanvas: invalid shared canvas"),
+                    OUString(RTL_CONSTASCII_USTRINGPARAM("PresenterCanvas: invalid shared canvas")),
                     static_cast<XWeak*>(this),
                     2);
             }
@@ -248,7 +249,7 @@ void SAL_CALL PresenterCanvas::initialize (
             if ( ! (rArguments[4] >>= mxWindow))
             {
                 throw lang::IllegalArgumentException(
-                    OUString::createFromAscii("PresenterCanvas: invalid window"),
+                    OUString(RTL_CONSTASCII_USTRINGPARAM("PresenterCanvas: invalid window")),
                     static_cast<XWeak*>(this),
                     3);
             }
@@ -269,7 +270,7 @@ void SAL_CALL PresenterCanvas::initialize (
     else
     {
         throw RuntimeException(
-            OUString::createFromAscii("PresenterCanvas: invalid number of arguments"),
+            OUString(RTL_CONSTASCII_USTRINGPARAM("PresenterCanvas: invalid number of arguments")),
                 static_cast<XWeak*>(this));
     }
 }
@@ -1226,3 +1227,5 @@ void PresenterCustomSprite::ThrowIfDisposed (void)
 
 
 } } // end of namespace ::sd::presenter
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
