@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
     /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,19 +29,13 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sd.hxx"
 #include <sfx2/dispatch.hxx>
-#ifndef _MSGBOX_HXX //autogen
 #include <vcl/msgbox.hxx>
-#endif
 #include <svx/svdpagv.hxx>
 #include <sfx2/request.hxx>
 #include <svl/style.hxx>
 #include <editeng/outliner.hxx>
-#ifndef _VIEW3D_HXX //autogen
 #include <svx/view3d.hxx>
-#endif
-#ifndef _SVXIDS_HRC //autogen
 #include <svx/svxids.hrc>
-#endif
 #include <svx/svdotext.hxx>
 #include <svx/svdograf.hxx>
 #include <svx/svdogrp.hxx>
@@ -162,10 +157,10 @@ void DrawView::ModelHasChanged()
 |*
 \************************************************************************/
 
-BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
-                                            BOOL bReplaceAll)
+sal_Bool DrawView::SetAttributes(const SfxItemSet& rSet,
+                                            sal_Bool bReplaceAll)
 {
-    BOOL bOk = FALSE;
+    sal_Bool bOk = sal_False;
 
     // wird eine Masterpage bearbeitet?
     if ( mpDrawViewShell && mpDrawViewShell->GetEditMode() == EM_MASTERPAGE )
@@ -180,11 +175,11 @@ BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
             // Textedit
             String aTemplateName(aLayoutName);
 
-            UINT32 nInv = pEditObject->GetObjInventor();
+            sal_uInt32 nInv = pEditObject->GetObjInventor();
 
             if (nInv == SdrInventor)
             {
-                UINT16 eObjKind = pEditObject->GetObjIdentifier();
+                sal_uInt16 eObjKind = pEditObject->GetObjIdentifier();
                 PresObjKind ePresObjKind = rPage.GetPresObjKind(pEditObject);
 
                 if ( ePresObjKind == PRESOBJ_TITLE ||
@@ -204,18 +199,18 @@ BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
 
                     pSheet->GetItemSet().Put(aTempSet);
                     pSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
-                    bOk = TRUE;
+                    bOk = sal_True;
                 }
                 else if (eObjKind == OBJ_OUTLINETEXT)
                 {
                     // Presentation object outline
                     OutlinerView* pOV	= GetTextEditOutlinerView();
                     ::Outliner* pOutliner = pOV->GetOutliner();
-                    List*		  pList = (List*)pOV->CreateSelectionList();
+
                     aTemplateName += String(SdResId(STR_LAYOUT_OUTLINE));
 
-                    pOutliner->SetUpdateMode(FALSE);
-                    mpDocSh->SetWaitCursor( TRUE );
+                    pOutliner->SetUpdateMode(sal_False);
+                    mpDocSh->SetWaitCursor( sal_True );
 
                     // Platzhalter durch Vorlagennamen ersetzen
                     String aComment(SdResId(STR_UNDO_CHANGE_PRES_OBJECT));
@@ -224,11 +219,16 @@ BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
                     aComment.Insert( String((SdResId(STR_PSEUDOSHEET_OUTLINE))), nPos);
                     mpDocSh->GetUndoManager()->EnterListAction( aComment, String() );
 
-                    Paragraph* pPara = (Paragraph*)pList->Last();
+                    std::vector<Paragraph*> aSelList;
+                    pOV->CreateSelectionList(aSelList);
+
+                    std::vector<Paragraph*>::reverse_iterator iter = aSelList.rbegin();
+                    Paragraph* pPara = iter != aSelList.rend() ? *iter : NULL;
+
                     while (pPara)
                     {
-                        ULONG nParaPos = pOutliner->GetAbsPos( pPara );
-                        sal_Int16 nDepth = pOutliner->GetDepth( (USHORT) nParaPos );
+                        sal_uLong nParaPos = pOutliner->GetAbsPos( pPara );
+                        sal_Int16 nDepth = pOutliner->GetDepth( (sal_uInt16) nParaPos );
                         String aName(rPage.GetLayoutName());
                         aName += (sal_Unicode)(' ');
                         aName += String::CreateFromInt32( (nDepth <= 0) ? 1 : nDepth + 1 );
@@ -265,20 +265,20 @@ BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
                                 pOutlSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
                         }
 
-                        pPara = (Paragraph*)pList->Prev();
+                        ++iter;
+                        pPara = iter != aSelList.rend() ? *iter : NULL;
 
                         if( !pPara && nDepth > 0 &&  rSet.GetItemState( EE_PARA_NUMBULLET ) == SFX_ITEM_ON &&
-                            pOutliner->GetDepth( (USHORT) pOutliner->GetAbsPos( (Paragraph*) pList->First() ) ) > 0 )
+                            pOutliner->GetDepth( (sal_uInt16) pOutliner->GetAbsPos(*(aSelList.begin())) ) > 0 )
                             pPara = pOutliner->GetParagraph( 0 );  // Put NumBulletItem in outline level 1
                     }
 
-                    mpDocSh->SetWaitCursor( FALSE );
-                    pOV->GetOutliner()->SetUpdateMode(TRUE);
+                    mpDocSh->SetWaitCursor( sal_False );
+                    pOV->GetOutliner()->SetUpdateMode(sal_True);
 
                     mpDocSh->GetUndoManager()->LeaveListAction();
 
-                    delete pList;
-                    bOk = TRUE;
+                    bOk = sal_True;
                 }
                 else
                 {
@@ -290,15 +290,15 @@ BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
         {
             // Selection
             const SdrMarkList& rList = GetMarkedObjectList();
-            ULONG nMarkCount		 = rList.GetMarkCount();
-            for (ULONG nMark = 0; nMark < nMarkCount; nMark++)
+            sal_uLong nMarkCount		 = rList.GetMarkCount();
+            for (sal_uLong nMark = 0; nMark < nMarkCount; nMark++)
             {
                 SdrObject* pObject = rList.GetMark(nMark)->GetMarkedSdrObj();
-                UINT32 nInv = pObject->GetObjInventor();
+                sal_uInt32 nInv = pObject->GetObjInventor();
 
                 if (nInv == SdrInventor)
                 {
-                    UINT16 eObjKind = pObject->GetObjIdentifier();
+                    sal_uInt16 eObjKind = pObject->GetObjIdentifier();
                     PresObjKind ePresObjKind = rPage.GetPresObjKind(pObject);
                     String aTemplateName(aLayoutName);
 
@@ -319,13 +319,13 @@ BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
 
                         pSheet->GetItemSet().Put(aTempSet,false);
                         pSheet->Broadcast(SfxSimpleHint(SFX_HINT_DATACHANGED));
-                        bOk = TRUE;
+                        bOk = sal_True;
                     }
                     else if (eObjKind == OBJ_OUTLINETEXT)
                     {
                         // Presentation object outline
                         aTemplateName += String(SdResId(STR_LAYOUT_OUTLINE));
-                        for (USHORT nLevel = 9; nLevel > 0; nLevel--)
+                        for (sal_uInt16 nLevel = 9; nLevel > 0; nLevel--)
                         {
                             String aName(rPage.GetLayoutName());
                             aName += (sal_Unicode)(' ');
@@ -376,7 +376,7 @@ BOOL DrawView::SetAttributes(const SfxItemSet& rSet,
                             nWhich = aWhichIter.NextWhich();
                         }
 
-                        bOk = TRUE;
+                        bOk = sal_True;
                     }
                 }
             }
@@ -414,7 +414,7 @@ void DrawView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
             mpDrawViewShell->ResetActualLayer();
         }
 
-        // #94278# switch to that page when it's not a master page
+        // switch to that page when it's not a master page
         if(HINT_SWITCHTOPAGE == eHintKind)
         {
             const SdrPage* pPage = ((const SdrHint&)rHint).GetPage();
@@ -439,7 +439,7 @@ void DrawView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
 |*
 \************************************************************************/
 
-void DrawView::BlockPageOrderChangedHint(BOOL bBlock)
+void DrawView::BlockPageOrderChangedHint(sal_Bool bBlock)
 {
     if (bBlock)
         mnPOCHSmph++;
@@ -457,19 +457,19 @@ void DrawView::BlockPageOrderChangedHint(BOOL bBlock)
 |*
 \************************************************************************/
 
-BOOL DrawView::SetStyleSheet(SfxStyleSheet* pStyleSheet, BOOL bDontRemoveHardAttr)
+sal_Bool DrawView::SetStyleSheet(SfxStyleSheet* pStyleSheet, sal_Bool bDontRemoveHardAttr)
 {
-    BOOL bResult = TRUE;
+    sal_Bool bResult = sal_True;
 
     // wird eine Masterpage bearbeitet?
     if (mpDrawViewShell && mpDrawViewShell->GetEditMode() == EM_MASTERPAGE)
     {
-        if (IsPresObjSelected(FALSE, TRUE))
+        if (IsPresObjSelected(sal_False, sal_True))
         {
 
             InfoBox(mpDrawViewShell->GetActiveWindow(),
                     String(SdResId(STR_ACTION_NOTPOSSIBLE))).Execute();
-            bResult = FALSE;
+            bResult = sal_False;
         }
         else
         {
@@ -497,7 +497,7 @@ void DrawView::CompleteRedraw(OutputDevice* pOutDev, const Region& rReg, sdr::co
         mpVDev = NULL;
     }
 
-    BOOL bStandardPaint = TRUE;
+    sal_Bool bStandardPaint = sal_True;
 
     SdDrawDocument* pDoc = mpDocShell->GetDoc();
     if( pDoc && pDoc->GetDocumentType() == DOCUMENT_TYPE_IMPRESS)
@@ -510,7 +510,7 @@ void DrawView::CompleteRedraw(OutputDevice* pOutDev, const Region& rReg, sdr::co
             {
                 if( pShowWindow == pOutDev )
                     PresPaint(rReg);
-                bStandardPaint = FALSE;
+                bStandardPaint = sal_False;
             }
         }
     }
@@ -542,7 +542,7 @@ void DrawView::PresPaint(const Region& rRegion)
 |* erschienene Animationsobjekte in der Diashow)
 \************************************************************************/
 
-BOOL DrawView::IsObjMarkable(SdrObject* pObj, SdrPageView* pPV) const
+sal_Bool DrawView::IsObjMarkable(SdrObject* pObj, SdrPageView* pPV) const
 {
     return FmFormView::IsObjMarkable(pObj, pPV);;
 }
@@ -555,7 +555,7 @@ BOOL DrawView::IsObjMarkable(SdrObject* pObj, SdrPageView* pPV) const
 
 void DrawView::MakeVisible(const Rectangle& rRect, ::Window& rWin)
 {
-    if (!rRect.IsEmpty())
+    if (!rRect.IsEmpty() && mpDrawViewShell)
     {
         mpDrawViewShell->MakeVisible(rRect, rWin);
     }
@@ -594,11 +594,11 @@ void DrawView::DeleteMarked()
     SdPage* pPage = 0;
     bool bResetLayout = false;
 
-    const ULONG nMarkCount = GetMarkedObjectList().GetMarkCount();
+    const sal_uLong nMarkCount = GetMarkedObjectList().GetMarkCount();
     if( nMarkCount )
     {
         SdrMarkList aList( GetMarkedObjectList() );
-        for (ULONG nMark = 0; nMark < nMarkCount; nMark++)
+        for (sal_uLong nMark = 0; nMark < nMarkCount; nMark++)
         {
             SdrObject* pObj = aList.GetMark(nMark)->GetMarkedSdrObj();
             if( pObj && !pObj->IsEmptyPresObj() && pObj->GetUserCall() )
@@ -649,3 +649,5 @@ void DrawView::DeleteMarked()
 }
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
