@@ -73,7 +73,6 @@
 #include <svx/bmpmask.hxx>
 #include "LayerTabBar.hxx"
 
-// #97016# IV
 #include <svx/svditer.hxx>
 
 namespace sd {
@@ -95,7 +94,7 @@ using namespace ::com::sun::star::drawing;
 
 void DrawViewShell::DeleteActualPage()
 {
-    USHORT			nPage = maTabControl.GetCurPageId() - 1;
+    sal_uInt16			nPage = maTabControl.GetCurPageId() - 1;
 
     mpDrawView->SdrEndTextEdit();
 
@@ -108,7 +107,7 @@ void DrawViewShell::DeleteActualPage()
     }
     catch( Exception& )
     {
-        DBG_ERROR("SelectionManager::DeleteSelectedMasterPages(), exception caught!");
+        OSL_FAIL("SelectionManager::DeleteSelectedMasterPages(), exception caught!");
     }
 }
 
@@ -125,13 +124,13 @@ void DrawViewShell::DeleteActualLayer()
     String         aString(SdResId(STR_ASK_DELETE_LAYER));
 
     // Platzhalter ersetzen
-    USHORT nPos = aString.Search(sal_Unicode('$'));
+    sal_uInt16 nPos = aString.Search(sal_Unicode('$'));
     aString.Erase(nPos, 1);
     aString.Insert(rName, nPos);
 
     if (QueryBox(GetActiveWindow(), WB_YES_NO, aString).Execute() == RET_YES)
     {
-        const SdrLayer* pLayer = rAdmin.GetLayer(rName, FALSE);
+        const SdrLayer* pLayer = rAdmin.GetLayer(rName, sal_False);
         mpDrawView->DeleteLayer( pLayer->GetName() );
 
         // damit TabBar und Window neu gezeichnet werden;
@@ -151,13 +150,12 @@ void DrawViewShell::DeleteActualLayer()
 |*
 \************************************************************************/
 
-BOOL DrawViewShell::KeyInput (const KeyEvent& rKEvt, ::sd::Window* pWin)
+sal_Bool DrawViewShell::KeyInput (const KeyEvent& rKEvt, ::sd::Window* pWin)
 {
-    BOOL bRet = FALSE;
+    sal_Bool bRet = sal_False;
 
     if ( !IsInputLocked() || ( rKEvt.GetKeyCode().GetCode() == KEY_ESCAPE ) )
     {
-        // #97016# IV
         if(KEY_RETURN == rKEvt.GetKeyCode().GetCode()
             && rKEvt.GetKeyCode().IsMod1()
             && GetView()->IsTextEdit())
@@ -179,7 +177,7 @@ BOOL DrawViewShell::KeyInput (const KeyEvent& rKEvt, ::sd::Window* pWin)
 
                 // look for a new candidate, a successor of pOldObj
                 SdrObjListIter aIter(*pActualPage, IM_DEEPNOGROUPS);
-                BOOL bDidVisitOldObject(FALSE);
+                sal_Bool bDidVisitOldObject(sal_False);
 
                 while(aIter.IsMore() && !pCandidate)
                 {
@@ -199,7 +197,7 @@ BOOL DrawViewShell::KeyInput (const KeyEvent& rKEvt, ::sd::Window* pWin)
 
                         if(pObj == pOldObj)
                         {
-                            bDidVisitOldObject = TRUE;
+                            bDidVisitOldObject = sal_True;
                         }
                     }
                 }
@@ -247,13 +245,13 @@ void DrawViewShell::StartRulerDrag (
     if ( rRuler.GetExtraRect().IsInside(rMEvt.GetPosPixel()) )
     {
         mpDrawView->BegSetPageOrg(aWPos);
-        mbIsRulerDrag = TRUE;
+        mbIsRulerDrag = sal_True;
     }
     else
     {
         // #i34536# if no guide-lines are visible yet, that show them
         if( ! mpDrawView->IsHlplVisible())
-            mpDrawView->SetHlplVisible( TRUE );
+            mpDrawView->SetHlplVisible( sal_True );
 
         SdrHelpLineKind eKind;
 
@@ -265,7 +263,7 @@ void DrawViewShell::StartRulerDrag (
             eKind = SDRHELPLINE_VERTICAL;
 
         mpDrawView->BegDragHelpLine(aWPos, eKind);
-        mbIsRulerDrag = TRUE;
+        mbIsRulerDrag = sal_True;
     }
 }
 
@@ -284,9 +282,8 @@ void DrawViewShell::MouseButtonDown(const MouseEvent& rMEvt,
     // opened by inplace client and we would deactivate the inplace client,
     // the contex menu is closed by VCL asynchronously which in the end
     // would work on deleted objects or the context menu has no parent anymore)
-    // See #126086# and #128122#
     SfxInPlaceClient* pIPClient = GetViewShell()->GetIPClient();
-    BOOL bIsOleActive = ( pIPClient && pIPClient->IsObjectInPlaceActive() );
+    sal_Bool bIsOleActive = ( pIPClient && pIPClient->IsObjectInPlaceActive() );
 
     if ( bIsOleActive && PopupMenu::IsInExecute() )
         return;
@@ -317,7 +314,7 @@ void DrawViewShell::MouseMove(const MouseEvent& rMEvt, ::sd::Window* pWin)
 
             if ( !aOutputArea.IsInside(rMEvt.GetPosPixel()) )
             {
-                BOOL bInsideOtherWindow = FALSE;
+                sal_Bool bInsideOtherWindow = sal_False;
 
                 if (mpContentWindow.get() != NULL)
                 {
@@ -326,7 +323,7 @@ void DrawViewShell::MouseMove(const MouseEvent& rMEvt, ::sd::Window* pWin)
 
                     Point aPos = mpContentWindow->GetPointerPosPixel();
                     if ( aOutputArea.IsInside(aPos) )
-                        bInsideOtherWindow = TRUE;
+                        bInsideOtherWindow = sal_True;
                 }
 
                 if (! GetActiveWindow()->HasFocus ())
@@ -345,7 +342,6 @@ void DrawViewShell::MouseMove(const MouseEvent& rMEvt, ::sd::Window* pWin)
                  pWin->CaptureMouse();
         }
 
-        // #109585#
         // Since the next MouseMove may execute a IsSolidDraggingNow() in
         // SdrCreateView::MovCreateObj and there the ApplicationBackgroundColor
         // is needed it is necessary to set it here.
@@ -415,9 +411,9 @@ void DrawViewShell::MouseMove(const MouseEvent& rMEvt, ::sd::Window* pWin)
             }
 
             ( (SvxBmpMask*) GetViewFrame()->GetChildWindow( SvxBmpMaskChildWindow::GetChildWindowId() )->GetWindow() )->
-                SetColor( Color( (BYTE) ( nRed / fDiv + .5 ),
-                                 (BYTE) ( nGreen / fDiv + .5 ),
-                                 (BYTE) ( nBlue / fDiv + .5 ) ) );
+                SetColor( Color( (sal_uInt8) ( nRed / fDiv + .5 ),
+                                 (sal_uInt8) ( nGreen / fDiv + .5 ),
+                                 (sal_uInt8) ( nBlue / fDiv + .5 ) ) );
         }
     }
 }
@@ -460,7 +456,7 @@ void DrawViewShell::MouseButtonUp(const MouseEvent& rMEvt, ::sd::Window* pWin)
             }
 
             GetActiveWindow()->ReleaseMouse();
-            mbIsRulerDrag = FALSE;
+            mbIsRulerDrag = sal_False;
         }
         else
             ViewShell::MouseButtonUp(rMEvt, pWin);
@@ -479,9 +475,8 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
     // menu from an inplace client is closed. Now we have the chance to
     // deactivate the inplace client without any problem regarding parent
     // windows and code on the stack.
-    // For more information, see #126086# and #128122#
     SfxInPlaceClient* pIPClient = GetViewShell()->GetIPClient();
-    BOOL bIsOleActive = ( pIPClient && pIPClient->IsObjectInPlaceActive() );
+    sal_Bool bIsOleActive = ( pIPClient && pIPClient->IsObjectInPlaceActive() );
     if ( bIsOleActive && ( rCEvt.GetCommand() == COMMAND_CONTEXTMENU ))
     {
         // Deactivate OLE object
@@ -509,7 +504,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                 if( GetActiveWindow() )
                     aPos = GetActiveWindow()->PixelToLogic( rCEvt.GetMousePosPixel() );
 
-                if( !mpDrawView->InsertData( aDataHelper, aPos, nDnDAction, FALSE ) )
+                if( !mpDrawView->InsertData( aDataHelper, aPos, nDnDAction, sal_False ) )
                 {
                     INetBookmark	aINetBookmark( aEmptyStr, aEmptyStr );
 
@@ -528,24 +523,23 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
         else if( rCEvt.GetCommand() == COMMAND_CONTEXTMENU && !bNativeShow &&
                  pWin != NULL && !mpDrawView->IsAction() && !SD_MOD()->GetWaterCan() )
         {
-            USHORT nSdResId = 0;          // ResourceID fuer Popup-Menue
-            BOOL bGraphicShell = this->ISA(GraphicViewShell);
+            sal_uInt16 nSdResId = 0;          // ResourceID fuer Popup-Menue
+            sal_Bool bGraphicShell = this->ISA(GraphicViewShell);
 
             // Ist ein Fangobjekt unter dem Mauszeiger?
             SdrPageView* pPV;
             Point	aMPos = pWin->PixelToLogic( maMousePos );
-            USHORT	nHitLog = (USHORT) GetActiveWindow()->PixelToLogic(
+            sal_uInt16	nHitLog = (sal_uInt16) GetActiveWindow()->PixelToLogic(
                 Size(FuPoor::HITPIX, 0 ) ).Width();
-            USHORT	nHelpLine;
+            sal_uInt16	nHelpLine;
             // fuer Klebepunkt
             SdrObject*	pObj = NULL;
-            USHORT		nPickId = 0;
+            sal_uInt16		nPickId = 0;
             // fuer Feldbefehl
             OutlinerView* pOLV = mpDrawView->GetTextEditOutlinerView();
             const SvxFieldItem* pFldItem = NULL;
             if( pOLV )
                 pFldItem = pOLV->GetFieldAtSelection();
-                //pFldItem = pOLV->GetFieldUnderMousePointer();
 
             // Hilfslinie
             if ( mpDrawView->PickHelpLine( aMPos, nHitLog, *GetActiveWindow(), nHelpLine, pPV) )
@@ -568,7 +562,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
             {
                 LanguageType eLanguage( LANGUAGE_SYSTEM );
 
-                // #101743# Format popup with outliner language, if possible
+                // Format popup with outliner language, if possible
                 if( pOLV->GetOutliner() )
                 {
                     ESelection aSelection( pOLV->GetSelection() );
@@ -587,13 +581,12 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                 if( pField )
                 {
                     SvxFieldItem aFieldItem( *pField, EE_FEATURE_FIELD );
-                    //pOLV->DeleteSelected(); <-- fehlt leider !
                     // Feld selektieren, so dass es beim Insert geloescht wird
                     ESelection aSel = pOLV->GetSelection();
-                    BOOL bSel = TRUE;
+                    sal_Bool bSel = sal_True;
                     if( aSel.nStartPos == aSel.nEndPos )
                     {
-                        bSel = FALSE;
+                        bSel = sal_False;
                         aSel.nEndPos++;
                     }
                     pOLV->SetSelection( aSel );
@@ -631,8 +624,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                                 if( (  rCEvt.IsMouseEvent() && pOutlinerView->IsWrongSpelledWordAtPos(aPos) ) ||
                                     ( !rCEvt.IsMouseEvent() && pOutlinerView->IsCursorAtWrongSpelledWord() ) )
                                 {
-                                    // #91457# Popup for Online-Spelling now handled by DrawDocShell
-                                    // Link aLink = LINK(GetDoc(), SdDrawDocument, OnlineSpellCallback);
+                                    // Popup for Online-Spelling now handled by DrawDocShell
                                     Link aLink = LINK(GetDocSh(), DrawDocShell, OnlineSpellCallback);
 
                                     if( !rCEvt.IsMouseEvent() )
@@ -665,8 +657,8 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                         }
                         else
                         {
-                            UINT32 nInv = pObj->GetObjInventor();
-                            UINT16 nId = pObj->GetObjIdentifier();
+                            sal_uInt32 nInv = pObj->GetObjInventor();
+                            sal_uInt16 nId = pObj->GetObjIdentifier();
 
                             if (nInv == SdrInventor)
                             {
@@ -747,7 +739,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                                         break;
                                 }
                             }
-                            else if( nInv == E3dInventor /*&& nId == E3D_POLYSCENE_ID*/)
+                            else if( nInv == E3dInventor )
                             {
                                 if( nId == E3D_POLYSCENE_ID || nId == E3D_SCENE_ID )
                                 {
@@ -785,7 +777,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                                                 RID_DRAW_NOSEL_POPUP;
                 }
             }
-            // Popup-Menue anzeigen
+            // show Popup-Menu
             if (nSdResId)
             {
                 GetActiveWindow()->ReleaseMouse();
@@ -794,7 +786,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                     GetViewFrame()->GetDispatcher()->ExecutePopup(SdResId(nSdResId));
                 else
                 {
-                    //#106326# don't open contextmenu at mouse position if not opened via mouse
+                    //don't open contextmenu at mouse position if not opened via mouse
 
                     //middle of the window if nothing is marked
                     Point aMenuPos(GetActiveWindow()->GetSizePixel().Width()/2
@@ -821,7 +813,7 @@ void DrawViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
                     //open context menu at that point
                     GetViewFrame()->GetDispatcher()->ExecutePopup(SdResId(nSdResId),GetActiveWindow(),&aMenuPos);
                 }
-                mbMousePosFreezed = FALSE;
+                mbMousePosFreezed = sal_False;
             }
         }
         else
@@ -846,7 +838,7 @@ void DrawViewShell::ShowMousePosInfo(const Rectangle& rRect,
         RulerLine	pVLines[2];
         long        nHOffs = 0L;
         long        nVOffs = 0L;
-        USHORT		nCnt;
+        sal_uInt16		nCnt;
 
         if (mpHorizontalRuler.get() != NULL)
             mpHorizontalRuler->SetLines();
@@ -908,23 +900,11 @@ void DrawViewShell::ShowMousePosInfo(const Rectangle& rRect,
     }
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void DrawViewShell::LockInput()
 {
     mnLockCount++;
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void DrawViewShell::UnlockInput()
 {
     DBG_ASSERT( mnLockCount, "Input for this shell is not locked!" );
@@ -937,7 +917,7 @@ void DrawViewShell::UnlockInput()
 
 void DrawViewShell::ShowSnapLineContextMenu (
     SdrPageView& rPageView,
-    const USHORT nSnapLineIndex,
+    const sal_uInt16 nSnapLineIndex,
     const Point& rMouseLocation)
 {
     const SdrHelpLine& rHelpLine (rPageView.GetHelpLines()[nSnapLineIndex]);
@@ -964,9 +944,9 @@ void DrawViewShell::ShowSnapLineContextMenu (
             String(SdResId(STR_POPUP_DELETE_SNAPLINE)));
     }
 
-    pMenu->RemoveDisabledEntries(FALSE, FALSE);
+    pMenu->RemoveDisabledEntries(sal_False, sal_False);
 
-    const USHORT nResult = pMenu->Execute(
+    const sal_uInt16 nResult = pMenu->Execute(
         GetActiveWindow(),
         Rectangle(rMouseLocation, Size(10,10)),
         POPUPMENU_EXECUTE_DOWN);
